@@ -59,6 +59,7 @@
 
 // session includes
 #include "AbiCollab.h"
+#include <xp/AbiCollab_Packet.h>
 
 // account handler includes
 #ifdef ABICOLLAB_HANDLER_XMPP
@@ -70,6 +71,9 @@
 #ifdef ABICOLLAB_HANDLER_SUGAR
 #include <backends/sugar/unix/SugarUnixAccountHandler.h>
 #endif
+#ifdef ABICOLLAB_HANDLER_SERVICE
+#include <backends/service/xp/ServiceAccountHandler.h>
+#endif
 
 // event includes
 #include <backends/xp/Event.h>
@@ -92,12 +96,17 @@
 // ... and include ourselves :)
 #include "AbiCollabSessionManager.h"
 
+#ifdef WIN32
+// This is ugly, but I get segfaults in debug mode if I put this function in the .h file.
+HINSTANCE AbiCollabSessionManager::getInstance() { return m_hModule; }
+#endif
+
 // We, the mighty SessionManager, manage it all!
 AbiCollabSessionManager s_AbiCollabSessionManager;
 AbiCollabSessionManager * AbiCollabSessionManager::m_pManager = NULL;
 AbiCollabSessionManager * AbiCollabSessionManager::getManager() { return m_pManager; }
 
-UT_Error AbiCollabSessionManager::serializeDocument(const PD_Document* pDoc, UT_UTF8String& document)
+UT_Error AbiCollabSessionManager::serializeDocument(const PD_Document* pDoc, std::string& document, bool encodeBase64)
 {
 	UT_return_val_if_fail(pDoc, false);
 
@@ -107,7 +116,7 @@ UT_Error AbiCollabSessionManager::serializeDocument(const PD_Document* pDoc, UT_
 	// maskExport();
 	GsfOutputMemory* sink = GSF_OUTPUT_MEMORY(gsf_output_memory_new());
 	GsfOutput* gzSink = gsf_output_gzip_new(GSF_OUTPUT(sink), NULL);
-	UT_Error result = const_cast<PD_Document*>(pDoc)->saveAs(GSF_OUTPUT(gzSink), IE_Imp::fileTypeForSuffix(".abw"), true);
+	UT_Error result = const_cast<PD_Document*>(pDoc)->saveAs(GSF_OUTPUT(gzSink), IE_Exp::fileTypeForSuffix(".abw"), true);
 	gsf_output_close(GSF_OUTPUT(gzSink));
 	// unmaskExport();
 	
@@ -115,11 +124,20 @@ UT_Error AbiCollabSessionManager::serializeDocument(const PD_Document* pDoc, UT_
 	{
 		guint32 size = gsf_output_size (GSF_OUTPUT(sink));
 		const guint8* zabwBuf = gsf_output_memory_get_bytes (sink);
-			
-		// this would be more efficient if we had a GsfOutputBase64.. ah well, this will do for now
-		guint8* base64zabwBuf = gsf_base64_encode_simple(zabwBuf, size);
-		document += (char*)base64zabwBuf;
-		free(base64zabwBuf);
+		
+		if (encodeBase64)
+		{
+			// this would be more efficient if we had a GsfOutputBase64.. ah well, this will do for now
+			guint8* base64zabwBuf = gsf_base64_encode_simple(zabwBuf, size);
+			document += (char*)base64zabwBuf;
+			free(base64zabwBuf);
+		}
+		else
+		{
+			// just copy raw zipped data into string
+			document.resize( size );
+			memcpy( &document[0], zabwBuf, size );
+		}
 	} 
 	else
 		UT_DEBUGMSG(("Failed to export! Handle this gracefully!\n"));
@@ -129,16 +147,26 @@ UT_Error AbiCollabSessionManager::serializeDocument(const PD_Document* pDoc, UT_
 	return result;
 }
 
-UT_Error AbiCollabSessionManager::deserializeDocument(PD_Document** pDoc, UT_UTF8String& document)
+UT_Error AbiCollabSessionManager::deserializeDocument(PD_Document** pDoc, std::string& document, bool isEncodedBase64)
 {
 	UT_Error res = UT_ERROR;
 
-	// really bad abuse of UT_UTF8String's below, but more efficient than copying 
+	// really bad abuse of std::string's below, but more efficient than copying 
 	// the whole buffer (which could be massive) into a temporary buffer
-	char* base64gzBuf = const_cast<char*>(document.utf8_str());
-	size_t gzbufLen = gsf_base64_decode_simple((guint8*)base64gzBuf, strlen(base64gzBuf));
-	char* gzBuf = base64gzBuf;
-	GsfInput *source = gsf_input_memory_new((guint8*)gzBuf, gzbufLen, false);
+	GsfInput *source;
+	if (isEncodedBase64)
+	{
+		char* base64gzBuf = const_cast<char*>(document.c_str());
+		size_t gzbufLen = gsf_base64_decode_simple((guint8*)base64gzBuf, strlen(base64gzBuf));
+		char* gzBuf = base64gzBuf;
+		source = gsf_input_memory_new((guint8*)gzBuf, gzbufLen, false);
+	}
+	else
+	{
+		// string contains raw zipped data
+		source = gsf_input_memory_new((guint8*)document.c_str(), document.size(), false);
+	}
+
 	if (source)
 	{
 		GsfInput *gzabwBuf = gsf_input_gzip_new (source, NULL); // todo: don't pass null here, but check for errors
@@ -210,6 +238,9 @@ bool AbiCollabSessionManager::registerAccountHandlers()
 	UT_DEBUGMSG(("Registering the sugar account handler!\n"));
 	AccountHandler* pSugarHandler = new SugarAccountHandler();
 	addAccount(pSugarHandler);
+#endif
+#ifdef ABICOLLAB_HANDLER_SERVICE
+	m_regAccountHandlers.push_back(ServiceAccountHandlerConstructor);
 #endif
 	return true;
 }
@@ -265,7 +296,7 @@ void AbiCollabSessionManager::loadProfile()
 
 							// find the account handler belonging to this type
 							UT_UTF8String handlerType = reinterpret_cast<char *>(xmlGetProp(accountNode, reinterpret_cast<const xmlChar*>("type"))); 
-							for (UT_sint32 i = 0; i < m_regAccountHandlers.getItemCount(); i++)
+							for (UT_uint32 i = 0; i < m_regAccountHandlers.getItemCount(); i++)
 							{
 								AccountHandlerConstructor constructor = m_regAccountHandlers.getNthItem(i);
 								AccountHandler* pHandler = constructor();
@@ -371,7 +402,7 @@ void AbiCollabSessionManager::storeProfile()
 				// TODO: one could check every return value here, but I'm lazy right now
 				xmlTextWriterStartElement(writer, reinterpret_cast<const xmlChar*>("AbiCollabProfile"));
 				
-				for (UT_sint32 i = 0; i < m_vecAccounts.getItemCount(); i++)
+				for (UT_uint32 i = 0; i < m_vecAccounts.getItemCount(); i++)
 				{
 					AccountHandler* pHandler = m_vecAccounts.getNthItem(i);
 					if (pHandler)
@@ -390,7 +421,7 @@ void AbiCollabSessionManager::storeProfile()
 						// write out the account handler buddies
 						xmlTextWriterStartElement(writer, reinterpret_cast<const xmlChar*>("buddies"));
 						
-						for (UT_sint32 j = 0; j < pHandler->getBuddies().getItemCount(); j++)
+						for (UT_uint32 j = 0; j < pHandler->getBuddies().getItemCount(); j++)
 						{
 							Buddy* pBuddy = pHandler->getBuddies().getNthItem(j);
 							if (pBuddy && !pBuddy->isVolatile())
@@ -451,7 +482,7 @@ void AbiCollabSessionManager::storeProfile()
 bool AbiCollabSessionManager::destroySession(PD_Document * pDoc)
 {
 	AbiCollab * pCollab = NULL;
-	UT_sint32 i = 0;
+	UT_uint32 i = 0;
 	for (i = 0; i < m_vecSessions.getItemCount(); i++)
 	{
 		pCollab = m_vecSessions.getNthItem(i);
@@ -473,7 +504,7 @@ bool AbiCollabSessionManager::destroySession(AbiCollab* pSession)
 {
 	UT_DEBUGMSG(("AbiCollabSessionManager::destroySession()\n"));
 
-	UT_sint32 i = 0;
+	UT_uint32 i = 0;
 	for (i = 0; i < m_vecSessions.getItemCount(); i++)
 	{
 		AbiCollab* pActiveSession = m_vecSessions.getNthItem(i);
@@ -504,7 +535,7 @@ void AbiCollabSessionManager::disconnectSession(AbiCollab* pSession)
 
 void AbiCollabSessionManager::disconnectSessions()
 {
-	for(UT_sint32 i = 0; i < m_vecSessions.getItemCount(); i++)
+	for(UT_uint32 i = 0; i < m_vecSessions.getItemCount(); i++)
 	{
 		AbiCollab* pSession = m_vecSessions.getNthItem(i);
 		if (pSession)
@@ -521,7 +552,7 @@ AbiCollab* AbiCollabSessionManager::getSession(PD_Document* pDoc)
 	UT_return_val_if_fail(pDoc, NULL);
 	
 	AbiCollab * pCollab = NULL;
-	UT_sint32 i = 0;
+	UT_uint32 i = 0;
 	for(i = 0; i < m_vecSessions.getItemCount(); i++)
 	{
 		pCollab = m_vecSessions.getNthItem(i);
@@ -540,7 +571,7 @@ AbiCollab* AbiCollabSessionManager::getSession(PD_Document* pDoc)
 AbiCollab* AbiCollabSessionManager::getSessionFromDocumentId(const UT_UTF8String& sDocumentId)
 {
 	AbiCollab * pCollab = NULL;
-	UT_sint32 i = 0;
+	UT_uint32 i = 0;
 	for(i = 0; i < m_vecSessions.getItemCount(); i++)
 	{
 		pCollab = m_vecSessions.getNthItem(i);
@@ -559,7 +590,7 @@ AbiCollab* AbiCollabSessionManager::getSessionFromDocumentId(const UT_UTF8String
 AbiCollab* AbiCollabSessionManager::getSessionFromSessionId(const UT_UTF8String& sSessionId)
 {
 	AbiCollab * pCollab = NULL;
-	UT_sint32 i = 0;
+	UT_uint32 i = 0;
 	for(i = 0; i < m_vecSessions.getItemCount(); i++)
 	{
 		pCollab = m_vecSessions.getNthItem(i);
@@ -574,16 +605,27 @@ AbiCollab* AbiCollabSessionManager::getSessionFromSessionId(const UT_UTF8String&
 	return NULL;
 }
 
-void AbiCollabSessionManager::startSession(PD_Document* pDoc)
+AbiCollab* AbiCollabSessionManager::startSession(PD_Document* pDoc, UT_UTF8String& sSessionId)
 {
 	UT_DEBUGMSG(("Starting collaboration session for document with id %s\n", pDoc->getDocUUIDString()));
-	AbiCollab* pAbiCollab = new AbiCollab(pDoc);
+	
+	if (sSessionId == "")
+	{
+		XAP_App* pApp = XAP_App::getApp();	
+		UT_UUID* pUUID = pApp->getUUIDGenerator()->createUUID();
+		pUUID->toString(sSessionId);
+	}
+
+	UT_DEBUGMSG(("Creating a new collaboration session with UUID: %s\n", sSessionId.utf8_str()));
+	AbiCollab* pAbiCollab = new AbiCollab(pDoc, sSessionId);
 	m_vecSessions.push_back(pAbiCollab);
 	
 	// notify all people we are sharing a new document
 	StartSessionEvent event;
 	event.setBroadcast(true);
 	signal(event);
+	
+	return pAbiCollab;
 }
 
 
@@ -645,14 +687,18 @@ void AbiCollabSessionManager::joinSessionInitiate(Buddy* pBuddy, DocHandle* pDoc
 
 void AbiCollabSessionManager::joinSession(const UT_UTF8String& sSessionId, PD_Document* pDoc, const UT_UTF8String& docUUID, UT_sint32 iRev, Buddy* pCollaborator)
 {
-	UT_return_if_fail(pCollaborator);
-	UT_return_if_fail(pDoc);	
-
 	UT_DEBUGMSG(("AbiCollabSessionManager::joinSession()\n"));
-	// TODO: open up a new frame, with a new document
+
+	UT_return_if_fail(pCollaborator);
+	UT_return_if_fail(pDoc);
 	
-	AbiCollab* pAbiCollab = new AbiCollab(sSessionId, pDoc, docUUID, iRev, pCollaborator);
-	m_vecSessions.push_back(pAbiCollab);
+	AbiCollab* pSession = 
+#ifdef ABICOLLAB_HANDLER_SUGAR		
+		new AbiCollab(sSessionId, pDoc, docUUID, iRev, pCollaborator, true);
+#else
+		new AbiCollab(sSessionId, pDoc, docUUID, iRev, pCollaborator);
+#endif
+	m_vecSessions.push_back(pSession);
 
 	// signal everyone that we have joined this session
 	JoinSessionEvent event(sSessionId);
@@ -660,6 +706,21 @@ void AbiCollabSessionManager::joinSession(const UT_UTF8String& sSessionId, PD_Do
 	signal(event);
 }
 
+void AbiCollabSessionManager::joinSession(AbiCollab* pSession, Buddy* pCollaborator)
+{
+	UT_DEBUGMSG(("AbiCollabSessionManager::joinSession()\n"));	
+
+	UT_return_if_fail(pSession);
+	UT_return_if_fail(pCollaborator);	
+
+	m_vecSessions.push_back(pSession);
+
+	// signal everyone that we have joined this session
+	JoinSessionEvent event(pSession->getSessionId());
+	event.addRecipient(pCollaborator);
+	signal(event);
+}
+
 void AbiCollabSessionManager::disjoinSession(const UT_UTF8String& sSessionId)
 {
 	UT_DEBUGMSG(("AbiCollabSessionManager::disjoinSession(%s)\n", sSessionId.utf8_str()));
@@ -694,7 +755,7 @@ bool AbiCollabSessionManager::isLocallyControlled(PD_Document* pDoc)
 	UT_return_val_if_fail(pDoc, false);
 	
 	// find the session belonging to this document, if any
-	for (UT_sint32 i = 0; i < m_vecSessions.getItemCount(); i++)
+	for (UT_uint32 i = 0; i < m_vecSessions.getItemCount(); i++)
 	{
 		AbiCollab* pSession = m_vecSessions.getNthItem(i);
 		if (pSession)
@@ -715,7 +776,7 @@ bool AbiCollabSessionManager::isInSession(PD_Document* pDoc)
 	UT_return_val_if_fail(pDoc, false);
 	
 	// find the session belonging to this document, if any
-	for (UT_sint32 i = 0; i < m_vecSessions.getItemCount(); i++)
+	for (UT_uint32 i = 0; i < m_vecSessions.getItemCount(); i++)
 	{
 		AbiCollab* pSession = m_vecSessions.getNthItem(i);
 		if (pSession)
@@ -734,7 +795,7 @@ bool AbiCollabSessionManager::isInSession(PD_Document* pDoc)
 bool AbiCollabSessionManager::isActive(const UT_UTF8String& sSessionId)
 {
 	// find a session with this session id
-	for (UT_sint32 i = 0; i < m_vecSessions.getItemCount(); i++)
+	for (UT_uint32 i = 0; i < m_vecSessions.getItemCount(); i++)
 	{	
 		AbiCollab* pSession = m_vecSessions.getNthItem(i);
 		if (pSession)
@@ -780,7 +841,7 @@ bool AbiCollabSessionManager::addAccount(AccountHandler* pHandler)
 
 void AbiCollabSessionManager::destroyAccounts(void)
 {
-	for (UT_sint32 i = 0; i < m_vecAccounts.getItemCount(); i++)
+	for (UT_uint32 i = 0; i < m_vecAccounts.getItemCount(); i++)
 	{
 		AccountHandler * pHandler = m_vecAccounts.getNthItem(i);
 		DELETEP(pHandler);
@@ -792,7 +853,7 @@ void AbiCollabSessionManager::destroyAccount(AccountHandler* pHandler)
 {
 	UT_return_if_fail(pHandler);
 
-	for (UT_sint32 i = 0; i < m_vecAccounts.getItemCount(); i++)
+	for (UT_uint32 i = 0; i < m_vecAccounts.getItemCount(); i++)
 	{
 		UT_continue_if_fail(m_vecAccounts.getNthItem(i));
 		
@@ -804,7 +865,7 @@ void AbiCollabSessionManager::destroyAccount(AccountHandler* pHandler)
 			
 			// drop all buddies that belong to the account that is being deleted
 			// from all active sessions
-			for (UT_sint32 j = 0; j < m_vecSessions.getItemCount(); j++)
+			for (UT_uint32 j = 0; j < m_vecSessions.getItemCount(); j++)
 			{
 				AbiCollab* pSession = m_vecSessions.getNthItem(j); 
 				UT_continue_if_fail(pSession);
@@ -834,7 +895,7 @@ void AbiCollabSessionManager::setDocumentHandles(Buddy& buddy, const UT_GenericV
 	// we'll use to determine which document handles do not exist anymore
 	std::vector<DocHandle*> oldDocHandles(buddy.getDocHandles());
 
-	for (UT_sint32 i = 0; i < vDocHandles.size(); i++)
+	for (UT_uint32 i = 0; i < vDocHandles.size(); i++)
 	{
 		DocHandle* pDocHandle = vDocHandles.getNthItem(i);
 		// sanity checking
@@ -921,193 +982,181 @@ void AbiCollabSessionManager::setDocumentHandles(Buddy& buddy, const UT_GenericV
 	}
 }
 
-void AbiCollabSessionManager::processSessionPacket(AccountHandler& handler, xmlNode* sessionNode, const UT_UTF8String& sBuddyName)
+bool AbiCollabSessionManager::processPacket(AccountHandler& handler, Packet* packet, const UT_UTF8String& sBuddyName) 
 {
-	UT_DEBUGMSG(("AbiCollabSessionManager::processSessionPacket()\n"));
-	UT_return_if_fail(sessionNode);
-	
+	UT_DEBUGMSG(("AbiCollabSessionManager::processPacket()\n"));
+	UT_return_val_if_fail(packet, false);
+
 	// TODO: it is rather inefficient to request a buddy for every packet
-	Buddy* pBuddy = handler.getBuddy(sBuddyName);
-	UT_return_if_fail(pBuddy);
+	Buddy* buddy = handler.getBuddy(sBuddyName);
+	UT_return_val_if_fail(buddy, false);
 	
-	SessionPacketFactory pFactory(sessionNode);
-	while (SessionPacket* pPacket = pFactory.getNextPacket())
+	// check if this is a simple import-meh-now-packet
+	PClassType pct = packet->getClassType();
+	if (pct>=_PCT_FirstChange && pct<=_PCT_LastChange) 
 	{
-		UT_UTF8String sSessionId = pPacket->getSessionId();
-		// TODO: shouldn't we use the document id as well ????
-		AbiCollab* pAbiCollab = getSessionFromSessionId(sSessionId);
-		if (pAbiCollab)
-		{
-			pAbiCollab->import(pPacket, *pBuddy);
+		// lookup session
+		SessionPacket* dsp = static_cast<SessionPacket*>( packet );
+		const UT_UTF8String& sessionId = dsp->getSessionId();
+		AbiCollab* pAbiCollab = getSessionFromSessionId(sessionId);
+		if (!pAbiCollab) {
+			UT_DEBUGMSG(("Unknown session id: '%s'", sessionId.utf8_str()));
+			UT_return_val_if_fail(pAbiCollab, true);
 		}
-		else
-			UT_DEBUGMSG(("AbiCollabSessionManager::processPacket() - received an incoming packet for an unknown (expired?) session (%s)\n", sSessionId.utf8_str()));
-	}
-}
-
-// TODO: this should go to a generic XML factory parsing routine
-void AbiCollabSessionManager::processEventPacket(AccountHandler& handler, xmlNode* eventNode, const UT_UTF8String& sBuddyName)
-{
-	UT_DEBUGMSG(("AbiCollabSessionManager::processEventPacket()\n"));
-	UT_return_if_fail(eventNode);
-	
-	UT_DEBUGMSG(("Got an event from buddy: %s\n", sBuddyName.utf8_str()));
-	
-	// Only one event per packet allowed for now
-	xmlNode* eventContentNode = eventNode->children; 
-	if (eventContentNode)
-	{
-		if (strcmp(reinterpret_cast<const char*>(eventContentNode->name), "StartSession") == 0)
-		{
-			// TODO: it is rather inefficient to request a buddy for every packet
-			Buddy* pBuddy = handler.getBuddy(sBuddyName);
-			UT_return_if_fail(pBuddy);
 		
-			StartSessionEvent event;
-			event.setBroadcast(true);
-			signal(event, pBuddy);
-		}
-		else if (strcmp(reinterpret_cast<const char*>(eventContentNode->name), "JoinSession") == 0)
-		{
-			// TODO: it is rather inefficient to request a buddy for every packet
-			Buddy* pBuddy = handler.getBuddy(sBuddyName);
-			UT_return_if_fail(pBuddy);
-			
-			UT_UTF8String joinedSessionId = reinterpret_cast<char *>(xmlGetProp(eventContentNode, reinterpret_cast<const xmlChar*>("sessionId")));		
-			
-			// someone who joined this session disconnected, remove him from the collaboration session
-			AbiCollab* pSession = getSessionFromSessionId(joinedSessionId);			
-			if (pSession)
-			{		
-				if (isLocallyControlled(pSession->getDocument()))
-				{
-					// we should already know this buddy, as we sent should have already added this
-					// buddy when responding to his JoinSessionRequest
-					// TODO: check this
-				}
-
-				// signal all
-				JoinSessionEvent event(joinedSessionId);
-				signal(event, pBuddy);				
-			}
-			else
-			{
-				// we don't know this session, don't forward the packet
-				UT_ASSERT_HARMLESS(UT_NOT_REACHED);			
-			}
-		}
-		else if (strcmp(reinterpret_cast<const char*>(eventContentNode->name), "DisjoinSession") == 0)
-		{
-			// TODO: it is rather inefficient to request a buddy for every packet
-			Buddy* pBuddy = handler.getBuddy(sBuddyName);
-			UT_return_if_fail(pBuddy);
-	
-			UT_UTF8String disjoinedSessionId = reinterpret_cast<char *>(xmlGetProp(eventContentNode, reinterpret_cast<const xmlChar*>("sessionId")));		
-		
-			// someone who joined this session disconnected, remove him from the collaboration session
-			AbiCollab* pSession = getSessionFromSessionId(disjoinedSessionId);			
-			if (pSession)
-			{
-				pSession->removeCollaborator(pBuddy);
-				
-				// signal all 
-				DisjoinSessionEvent event(disjoinedSessionId);
-				signal(event, pBuddy);
-			}
-			else
-			{
-				// we don't know this session, don't forward the packet
-				UT_ASSERT_HARMLESS(UT_NOT_REACHED);
-			}
-		}
-		else if (strcmp(reinterpret_cast<const char*>(eventContentNode->name), "CloseSession") == 0)
-		{
-			// TODO: it is rather inefficient to request a buddy for every packet
-			Buddy* pBuddy = handler.getBuddy(sBuddyName);
-			UT_return_if_fail(pBuddy);
-	
-			UT_UTF8String destroyedSessionId = reinterpret_cast<char *>(xmlGetProp(eventContentNode, reinterpret_cast<const xmlChar*>("sessionId")));
-			UT_DEBUGMSG(("Purging existing DocHandle (%s) for buddy (%s)\n", destroyedSessionId.utf8_str(), pBuddy->getName().utf8_str()));
-			pBuddy->destroyDocHandle(destroyedSessionId);
-			
-			// handle the event outselves
-			AbiCollab* pSession = getSessionFromSessionId(destroyedSessionId);
-			if (pSession)
-			{
-				if (!isLocallyControlled(pSession->getDocument()))
-				{
-					// the server hosting this session is gone, so let's disconnect as well
-					if (!destroySession(pSession))
-						UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
-
-					// signal all 
-					CloseSessionEvent event(destroyedSessionId);
-					signal(event, pBuddy);
-
-					// inform the user of the disconnect			
-					XAP_Frame *pFrame = XAP_App::getApp()->getLastFocussedFrame();
-					UT_return_if_fail(pFrame);
-					UT_UTF8String msg;
-					// TODO: make this localizable
-					UT_UTF8String_sprintf(msg, "This document is not being shared anymore by %s. You are disconnected from the collaboration session.", pBuddy->getName().utf8_str()); 
-					pFrame->showMessageBox(msg.utf8_str(), XAP_Dialog_MessageBox::b_O, XAP_Dialog_MessageBox::a_OK);
-				}
-				else
-				{
-					// someone who is not controlling this session sends out messages he closed it!
-					// we will not forward this packet
-					UT_ASSERT_HARMLESS(UT_NOT_REACHED);
-				}
-			}
-			else
-				UT_DEBUGMSG(("Ignoring a CloseSession event for unknown session (%s)\n", destroyedSessionId.utf8_str()));
-		}
-		else if (strcmp(reinterpret_cast<const char*>(eventContentNode->name), "AddBuddyRequest") == 0)
-		{
-			// TODO: move this to a seperate function
-		
-			// TODO: it is rather inefficient to request a buddy for every packet
-			Buddy* pBuddy = handler.getBuddy(sBuddyName);
-			if (!pBuddy)
-			{
-				PropertyMap vBuddyProps;
-				vBuddyProps.insert(PropertyMap::value_type("name", sBuddyName.utf8_str()));
-				Buddy* pBuddy = handler.constructBuddy(vBuddyProps);
-		
-				if (pBuddy)
-				{
-					// TODO: we don't handle request authorization yet. For now, just
-					// add this buddy to our list
-					AccountHandler* pHandler = pBuddy->getHandler();
-					if (pHandler)
-					{
-						// TODO: check if we don't already have this user in our list
-						pHandler->addBuddy(pBuddy);
-						AccountAddBuddyEvent newEvent;
-						signal(newEvent, pBuddy);
-					}
-					else
-						UT_ASSERT_HARMLESS(UT_NOT_REACHED);
-				}
-				else
-					UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
-
-				// This event should never be forwarded over a network;
-				// we've just handled it, so leave it at that
-			}
-			else
-			{
-				// we already know this buddy, do nothing for now
-			}
-		}		
-		else
-		{
-			UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
-		}
+		// handle packet!
+		pAbiCollab->import( dsp, *buddy );
+		return true;
 	}
 	else
-		UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
-}
+	{
+		// handle packet
+		switch (pct) {
+			case PCT_StartSessionEvent:
+			{
+				// TODO: it is rather inefficient to request a buddy for every packet
+				StartSessionEvent event;
+				event.setBroadcast(true);
+				signal( event, buddy );
+				return true;
+			}
+			
+			case PCT_JoinSessionEvent:
+			{
+				JoinSessionEvent* jse = static_cast<JoinSessionEvent*>( packet );
+				const UT_UTF8String& joinedSessionId = jse->getSessionId();
+				
+				// someone who joined this session disconnected, remove him from the collaboration session
+				AbiCollab* pSession = getSessionFromSessionId(joinedSessionId);			
+				if (pSession)
+				{		
+					if (isLocallyControlled( pSession->getDocument() ))
+					{
+						// we should already know this buddy, as we sent should have already added this
+						// buddy when responding to his JoinSessionRequest
+						// TODO: check this
+					}
+
+					// signal all
+					JoinSessionEvent event(joinedSessionId);
+					signal( event, buddy );				
+				}
+				else
+				{
+					// we don't know this session, don't forward the packet
+					UT_ASSERT_HARMLESS(UT_NOT_REACHED);			
+				}
+				return true;
+			}
+			
+			case PCT_DisjoinSessionEvent:
+			{
+				DisjoinSessionEvent* dse = static_cast<DisjoinSessionEvent*>( packet );
+				const UT_UTF8String& disjoinedSessionId = dse->getSessionId();
+			
+				// someone who joined this session disconnected, remove him from the collaboration session
+				AbiCollab* pSession = getSessionFromSessionId(disjoinedSessionId);			
+				if (pSession)
+				{
+					pSession->removeCollaborator( buddy );
+					
+					// signal all 
+					DisjoinSessionEvent event(disjoinedSessionId);
+					signal( event, buddy );
+				}
+				else
+				{
+					// we don't know this session, don't forward the packet
+					UT_ASSERT_HARMLESS(UT_NOT_REACHED);
+				}
+				return true;
+			}
+			
+			case PCT_CloseSessionEvent:
+			{
+				CloseSessionEvent* cse = static_cast<CloseSessionEvent*>( packet );
+				const UT_UTF8String& destroyedSessionId = cse->getSessionId();
+			
+				buddy->destroyDocHandle( destroyedSessionId );
+				
+				// handle the event outselves
+				AbiCollab* pSession = getSessionFromSessionId(destroyedSessionId);
+				if (pSession)
+				{
+					if (!isLocallyControlled(pSession->getDocument()))
+					{
+						// the server hosting this session is gone, so let's disconnect as well
+						if (!destroySession(pSession))
+							UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
+
+						// signal all 
+						CloseSessionEvent event( destroyedSessionId );
+						signal( event, buddy );
+
+						// inform the user of the disconnect			
+						XAP_Frame *pFrame = XAP_App::getApp()->getLastFocussedFrame();
+						UT_return_val_if_fail(pFrame, true);
+						UT_UTF8String msg;
+						// TODO: make this localizable
+						UT_UTF8String_sprintf(msg, "This document is not being shared anymore by %s. You are disconnected from the collaboration session.", buddy->getName().utf8_str()); 
+						pFrame->showMessageBox(msg.utf8_str(), XAP_Dialog_MessageBox::b_O, XAP_Dialog_MessageBox::a_OK);
+					}
+					else
+					{
+						// someone who is not controlling this session sends out messages he closed it!
+						// we will not forward this packet
+						UT_ASSERT_HARMLESS(UT_NOT_REACHED);
+					}
+				}
+				else
+					UT_DEBUGMSG(("Ignoring a CloseSession event for unknown session (%s)\n", destroyedSessionId.utf8_str()));
+				return true;
+			}
+			
+			case PCT_AccountAddBuddyRequestEvent:
+			{
+				// TODO: it is rather inefficient to request a buddy for every packet
+				Buddy* pBuddy = handler.getBuddy(sBuddyName);
+				if (!pBuddy)
+				{
+					PropertyMap vBuddyProps;
+					vBuddyProps.insert(PropertyMap::value_type("name", sBuddyName.utf8_str()));
+					Buddy* pBuddy = handler.constructBuddy(vBuddyProps);
+			
+					if (pBuddy)
+					{
+						// TODO: we don't handle request authorization yet. For now, just
+						// add this buddy to our list
+						AccountHandler* pHandler = pBuddy->getHandler();
+						if (pHandler)
+						{
+							// TODO: check if we don't already have this user in our list
+							pHandler->addBuddy(pBuddy);
+							AccountAddBuddyEvent newEvent;
+							signal(newEvent, pBuddy);
+						}
+						else
+							UT_ASSERT_HARMLESS(UT_NOT_REACHED);
+					}
+					else
+						UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
+
+					// This event should never be forwarded over a network;
+					// we've just handled it, so leave it at that
+				}
+				else
+				{
+					// we already know this buddy, do nothing for now
+				}
+				return true;
+			}
+			
+			default:
+				break;
+		}
+	}
+	return false;
+}	
 
 void AbiCollabSessionManager::registerEventListener(EventListener* pListener)
 {
@@ -1118,7 +1167,7 @@ void AbiCollabSessionManager::registerEventListener(EventListener* pListener)
 void AbiCollabSessionManager::unregisterEventListener(EventListener* pListener)
 {
 	UT_return_if_fail(pListener);
-	for (UT_sint32 i = 0; i < m_vecEventListeners.getItemCount(); i++)
+	for (UT_uint32 i = 0; i < m_vecEventListeners.getItemCount(); i++)
 	{
 		EventListener* pRegListener = m_vecEventListeners.getNthItem(i);
 		if (pRegListener == pListener)
@@ -1134,7 +1183,7 @@ void AbiCollabSessionManager::signal(const Event& event, const Buddy* pSource)
 	UT_DEBUGMSG(("AbiCollabSessionManager::signal()\n"));
 
 	// forward the event to all listeners
-	for (UT_sint32 i = 0; i < m_vecEventListeners.getItemCount(); i++)
+	for (UT_uint32 i = 0; i < m_vecEventListeners.getItemCount(); i++)
 	{
 		EventListener* pListener = m_vecEventListeners.getNthItem(i);
 		if (pListener)
