@@ -421,9 +421,13 @@ void ODe_Table_Cell::write(GsfOutput* pTableOutput, const UT_UTF8String& rSpaces
     output = rSpacesOffset;
     output += "<table:table-cell";
     ODe_writeAttribute(output, "table:style-name", m_styleName);
+    if(m_numberColumnsSpanned.size() > 0)
+      ODe_writeAttribute(output, "table:number-columns-spanned", m_numberColumnsSpanned);
+    if(m_numberRowsSpanned.size() > 0)
+      ODe_writeAttribute(output, "table:number-rows-spanned", m_numberRowsSpanned);
+
     output += ">\n";
     ODe_writeToFile(pTableOutput, output);
-    
     gsf_output_write (pTableOutput, gsf_output_size (m_pTextContent),
 		      gsf_output_memory_get_bytes (GSF_OUTPUT_MEMORY (m_pTextContent)));
 
