@@ -348,6 +348,8 @@ void ODi_Frame_ListenerState::_drawTextBox (const gchar** ppAtts,
                                            ODi_ListenerStateAction& rAction) {
 
     const gchar* attribs[3];
+    const gchar* pStyleName = NULL;
+    const ODi_Style_Style* pGraphicStyle = NULL;
     UT_UTF8String props;
     
     props = "frame-type:textbox";
@@ -363,11 +365,64 @@ void ODi_Frame_ListenerState::_drawTextBox (const gchar** ppAtts,
         return;
     }
     
-    // Hardcoded now, but not for long.
     if (!props.empty()) {
         props += "; ";
     }
-    props += "bot-style:1; left-style:1; right-style:1; top-style:1";
+
+    // TODO: translate border thicknesses
+
+    if (m_rElementStack.getStartTag(0)) {
+        pStyleName = m_rElementStack.getStartTag(0)->getAttributeValue("draw:style-name");
+    }
+
+    if (pStyleName) {
+        pGraphicStyle = m_pStyles->getGraphicStyle(pStyleName, m_bOnContentStream);
+    }
+
+    if (pGraphicStyle) {
+        // For now, we'll assume HAVE_BORDER_UNSPECIFIED == HAVE_BORDER_YES
+        if (pGraphicStyle->hasBottomBorder() != ODi_Style_Style::HAVE_BORDER_NO) {
+            props += "bot-style:1";
+            if(pGraphicStyle->getBorderBottom_color() && !pGraphicStyle->getBorderBottom_color()->empty()) {
+                props += "; bot-color:";
+                props += *(pGraphicStyle->getBorderBottom_color());
+            }
+        } else {
+            props += "bot-style:0";
+        }
+
+        if (pGraphicStyle->hasLeftBorder() != ODi_Style_Style::HAVE_BORDER_NO) {
+            props += "; left-style:1";
+            if(pGraphicStyle->getBorderLeft_color() && !pGraphicStyle->getBorderLeft_color()->empty()) {
+                props += "; left-color:";
+                props += *(pGraphicStyle->getBorderLeft_color());
+            }
+        } else {
+            props += "; left-style:0";
+        }
+
+        if (pGraphicStyle->hasRightBorder() != ODi_Style_Style::HAVE_BORDER_NO) {
+            props += "; right-style:1";
+            if(pGraphicStyle->getBorderRight_color() && !pGraphicStyle->getBorderRight_color()->empty()) {
+                props += "; right-color:";
+                props += *(pGraphicStyle->getBorderRight_color());
+            }
+        } else {
+            props += "; right-style:0";
+        }
+
+        if (pGraphicStyle->hasTopBorder() != ODi_Style_Style::HAVE_BORDER_NO) {
+            props += "; top-style:1";
+            if(pGraphicStyle->getBorderTop_color() && !pGraphicStyle->getBorderTop_color()->empty()) {
+                props += "; top-color:";
+                props += *(pGraphicStyle->getBorderTop_color());
+            }
+        } else {
+            props += "; top-style:0";
+        }
+    } else {  //just hard-code some defaults
+        props += "bot-style:1; left-style:1; right-style:1; top-style:1";
+    }
 
     attribs[0] = "props";
     attribs[1] = props.utf8_str();
