@@ -25,6 +25,7 @@
 // Internal includes
 #include "ODi_ListenerStateAction.h"
 #include "ODi_Style_Style.h"
+#include "ODi_ListLevelStyleFormats.h"
 
 // AbiWord includes
 #include <pd_Document.h>
@@ -404,7 +405,7 @@ void ODi_Bullet_ListLevelStyle::buildAbiPropsString() {
             break;
             
         default:
-            UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
+            UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
     }
 }
 
@@ -439,10 +440,10 @@ void ODi_Numbered_ListLevelStyle::startElement (const gchar* pName,
         UT_UTF8String prefix, suffix;
         
         pVal = UT_getAttribute ("style:num-format", ppAtts);
-        UT_ASSERT(pVal);
+        UT_ASSERT_HARMLESS(pVal);
         _setAbiListType(pVal);
 
-        if (!strcmp(pVal, "")) {
+        if (pVal && !strcmp(pVal, "")) {
             // We have an empty number format.
             
             // Empty list label or "invisible" list.
@@ -516,9 +517,13 @@ void ODi_Numbered_ListLevelStyle::buildAbiPropsString() {
         case UPPERROMAN_LIST:
             m_abiProperties += "Upper Roman List";
             break;
+
+        case ARABICNUMBERED_LIST:
+            m_abiProperties += "Arabic List";
+            break;
             
         default:
-            UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
+            UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
     }
 }
 
@@ -550,6 +555,9 @@ void ODi_Numbered_ListLevelStyle::_setAbiListType(const gchar* pStyleNumFormat)
     } else if (!strcmp(pStyleNumFormat, "I")) {
         UT_UTF8String_sprintf(m_abiListType, "%d", UPPERROMAN_LIST);
         
+    } else if (!strcmp(pStyleNumFormat, ODI_LISTLEVELSTYLE_ARABIC)) {
+        UT_UTF8String_sprintf(m_abiListType, "%d", ARABICNUMBERED_LIST);
+        
     } else {
         // Use an arbitrary list type.
         UT_UTF8String_sprintf(m_abiListType, "%d", NUMBERED_LIST);
