@@ -498,6 +498,26 @@ void ODi_Style_Style::_parse_style_graphicProperties(const gchar** ppProps) {
         m_wrap = pVal;
     }
 
+    pVal = UT_getAttribute("fo:border-top", ppProps);
+    if (pVal) {
+        _stripColorLength(m_borderTop_color, m_borderTop_thickness, m_haveTopBorder, pVal);
+    }
+
+    pVal = UT_getAttribute("fo:border-bottom", ppProps);
+    if (pVal) {
+        _stripColorLength(m_borderBottom_color, m_borderBottom_thickness, m_haveBottomBorder, pVal);
+    }
+
+    pVal = UT_getAttribute("fo:border-left", ppProps);
+    if (pVal) {
+        _stripColorLength(m_borderLeft_color, m_borderLeft_thickness, m_haveLeftBorder, pVal);
+    }
+
+    pVal = UT_getAttribute("fo:border-right", ppProps);
+    if (pVal) {
+        _stripColorLength(m_borderRight_color, m_borderRight_thickness, m_haveRightBorder, pVal);
+    }
+
     pVal = UT_getAttribute("fo:background-color", ppProps);
     if (pVal) {
         m_backgroundColor = pVal;
@@ -515,6 +535,22 @@ void ODi_Style_Style::_parse_style_tableProperties(const gchar** ppProps) {
     if (pVal) {
         m_backgroundColor = pVal;
     }
+
+    pVal = UT_getAttribute("fo:margin-left",ppProps);
+    if (pVal) {
+        m_TableMarginLeft = pVal;
+    }
+
+    pVal = UT_getAttribute("fo:margin-right",ppProps);
+    if (pVal) {
+        m_TableMarginRight = pVal;
+    }
+
+
+    pVal = UT_getAttribute("style:width",ppProps);
+    if (pVal) {
+        m_TableWidth = pVal;
+    }
 }
 
 
