@@ -111,10 +111,12 @@ void ODi_Table_ListenerState::startElement (const gchar* pName,
         }
         
     } else if (!strcmp(pName, "table:table-cell")) {
-        
         _parseCellStart (ppAtts, rAction);
     }
-    
+    else if(!strcmp(pName,"table:covered-table-cell")){
+      m_col++;
+    }
+
     m_elementLevel++;
 }
 
@@ -156,7 +158,7 @@ void ODi_Table_ListenerState::endElement (const gchar* pName,
     
         if (m_onFirstPass) {
             // Do nothing.
-        } else {
+        } else{
             m_pAbiDocument->appendStrux(PTX_EndCell,NULL);
         }
     }
@@ -193,7 +195,18 @@ void ODi_Table_ListenerState::_parseTableStart(const gchar** ppAtts,
                     props += pStyle->getBackgroundColor()->utf8_str();
                 }
             }
-            
+            // Left table pos
+            if (pStyle != NULL) {
+                if (!pStyle->getTableMarginLeft()->empty()) {
+		    if (!props.empty()) {
+		        props += "; ";
+		    }
+		    props += "table-column-leftpos:";
+		    props += pStyle->getTableMarginLeft()->utf8_str();
+		    
+                }
+            }
+  
             // Column widths
             if (m_gotAllColumnWidths) {
                 if (!props.empty()) {
@@ -210,6 +223,7 @@ void ODi_Table_ListenerState::_parseTableStart(const gchar** ppAtts,
             props += "table-row-heights:";
             props += m_rowHeights;
             
+	    
             
             if (!props.empty()) {
                 ppAttribs[0] = "props";
@@ -293,22 +307,33 @@ void ODi_Table_ListenerState::_parseCellStart (const gchar** ppAtts,
         const gchar* pVal;
         const ODi_Style_Style* pStyle = NULL;
         UT_sint32 colSpan;
-
+        UT_sint32 rowSpan;
         m_col++;
         
         
         pVal = UT_getAttribute("table:number-columns-spanned", ppAtts);
         if (pVal) {
             colSpan = atoi(pVal);
-            UT_ASSERT(colSpan > 0);
+            if (colSpan < 1) {
+                colSpan = 1;
+            }
         } else {
             colSpan = 1;
         }
+        pVal = UT_getAttribute("table:number-rows-spanned", ppAtts);
+        if (pVal) {
+            rowSpan = atoi(pVal);
+            if (rowSpan < 1) {
+                rowSpan = 1;
+            }
+        } else {
+            rowSpan = 1;
+        }
         
 
         props = UT_UTF8String_sprintf(
             "top-attach: %d; bot-attach: %d; left-attach: %d; right-attach: %d",
-            m_row-1, m_row, m_col-1, m_col + (colSpan-1));
+            m_row-1, m_row+(rowSpan-1), m_col-1, m_col + (colSpan-1));
 
         pVal = UT_getAttribute("table:style-name", ppAtts);
         if (pVal) {
@@ -322,7 +347,7 @@ void ODi_Table_ListenerState::_parseCellStart (const gchar** ppAtts,
             // Top border
             if (pStyle->hasTopBorder() == ODi_Style_Style::HAVE_BORDER_YES) {
 
-                props += "; top-style:1";
+                props += "; top-style:solid";
 
                 if (!pStyle->getBorderTop_thickness()->empty()) {
                     props += "; top-thickness:";
@@ -334,8 +359,15 @@ void ODi_Table_ListenerState::_parseCellStart (const gchar** ppAtts,
                     props += *(pStyle->getBorderTop_color());
                 }
                 
-            } else if (pStyle->hasTopBorder() == ODi_Style_Style::HAVE_BORDER_NO) {
-                props += "; top-style:0";
+            } 
+	    else if (pStyle->hasTopBorder() == ODi_Style_Style::HAVE_BORDER_NO) {
+	    //
+	    // Work Around for AbiWord Drawing bug/feature
+	    //
+	      if(pStyle->hasBottomBorder() == ODi_Style_Style::HAVE_BORDER_YES)
+                props += "; top-style:solid";
+	      else
+		props += "; top-style:none";
             }
             
             
@@ -343,7 +375,7 @@ void ODi_Table_ListenerState::_parseCellStart (const gchar** ppAtts,
             // Bottom border
             if (pStyle->hasBottomBorder() == ODi_Style_Style::HAVE_BORDER_YES) {
             
-                props += "; bot-style:1";
+                props += "; bot-style:solid";
             
                 if (!pStyle->getBorderBottom_thickness()->empty()) {
                     props += "; bot-thickness:";
@@ -356,7 +388,13 @@ void ODi_Table_ListenerState::_parseCellStart (const gchar** ppAtts,
                 }
             
             } else if (pStyle->hasBottomBorder() == ODi_Style_Style::HAVE_BORDER_NO) {
-                props += "; bot-style:0";
+	    //
+	    // Work Around for AbiWord Drawing bug/feature
+	    //
+	      if(pStyle->hasTopBorder() == ODi_Style_Style::HAVE_BORDER_YES)
+                props += "; bot-style:solid";
+	      else
+                props += "; bot-style:none";
             }
             
             
@@ -364,7 +402,7 @@ void ODi_Table_ListenerState::_parseCellStart (const gchar** ppAtts,
             // Left border
             if (pStyle->hasLeftBorder() == ODi_Style_Style::HAVE_BORDER_YES) {
             
-                props += "; left-style:1";
+                props += "; left-style:solid";
                 
                 if (!pStyle->getBorderLeft_thickness()->empty()) {
                     props += "; left-thickness:";
@@ -377,7 +415,7 @@ void ODi_Table_ListenerState::_parseCellStart (const gchar** ppAtts,
                 }
                 
             } else if (pStyle->hasLeftBorder() == ODi_Style_Style::HAVE_BORDER_NO) {
-                props += "; left-style:0";
+                props += "; left-style:none";
             }
             
 
@@ -385,7 +423,7 @@ void ODi_Table_ListenerState::_parseCellStart (const gchar** ppAtts,
             // Right border
             if (pStyle->hasRightBorder() == ODi_Style_Style::HAVE_BORDER_YES) {
             
-                props += "; right-style:1";
+                props += "; right-style:solid";
                 
                 if (!pStyle->getBorderRight_thickness()->empty()) {
                     props += "; right-thickness:";
@@ -398,7 +436,7 @@ void ODi_Table_ListenerState::_parseCellStart (const gchar** ppAtts,
                 }
                 
             } else if (pStyle->hasRightBorder() == ODi_Style_Style::HAVE_BORDER_NO) {
-                props += "; right-style:0";
+                props += "; right-style:none";
             }
             
             
