@@ -471,6 +471,9 @@ void ODi_TextContent_ListenerState::startElement (const gchar* pName,
         m_inAbiSection = true;
         m_bOnContentStream = true;
         
+    } else if (!strcmp(pName, "draw:g")) {
+       rAction.ignoreElement();  // ignore drawing shapes since AbiWord can't handle them
+
     } else if (!strcmp(pName, "table:table")) {
         _insureInSection();
         rAction.pushState("Table");
