@@ -1175,7 +1175,7 @@ private:
 
   UT_UTF8String m_curStyleName;
 
-  UT_GenericVector<gchar*>	m_vecInlineFmt;
+  UT_GenericVector<const gchar*>	m_vecInlineFmt;
   UT_NumberStack		m_stackFmtStartIndex;
   const OpenWriter_StylesStream_Listener * m_pSSListener;
 
