@@ -165,8 +165,8 @@ IE_Exp_LaTeX::~IE_Exp_LaTeX()
 /*****************************************************************/
 /*****************************************************************/
 typedef UT_UCSChar U16;
-static int wvConvertUnicodeToLaTeX(U16 char16,char*& out);
-static bool _convertLettersToSymbols(char c, char *& subst);
+static int wvConvertUnicodeToLaTeX(U16 char16, const char*& out);
+static bool _convertLettersToSymbols(char c, const char *& subst);
 
 #define BT_NORMAL		1
 #define BT_HEADING1		2
@@ -1007,7 +1007,7 @@ void s_LaTeX_Listener::_outputData(const UT_UCSChar * data, UT_uint32 length)
 
 	for (pData = data; (pData < data + length); /**/)
 	{
-		char* subst = "";
+		const char* subst = "";
 
 		if (m_bInSymbol)
 		{
@@ -1152,7 +1152,7 @@ void s_LaTeX_Listener::_outputData(const UT_UCSChar * data, UT_uint32 length)
 
 #define SUB(a,who) case a: subst = "\\(\\"who"\\)"; return true;
 #define SUBd(a,who) case a: subst = who; return true;
-static bool _convertLettersToSymbols(char c, char *& subst)
+static bool _convertLettersToSymbols(char c, const char *& subst)
 {
 	switch (c)
 	{
@@ -1574,7 +1574,7 @@ void s_LaTeX_Listener::_handleDataItems(void)
 #undef printf
 #define printf(x) out = (x); 
 
-static int wvConvertUnicodeToLaTeX(U16 char16,char*& out)
+static int wvConvertUnicodeToLaTeX(U16 char16,const char*& out)
 	{
 	out = ""; //this is needed
 
