@@ -280,7 +280,7 @@ int IE_Imp_MSWrite::read_pap ()
     unsigned char pap_page[0x80];
     static const char *text_align[] = { "left", "center", "right", "justify" };
 
-    gchar* pProps = "props";
+	const gchar* pProps = "props";
     UT_String propBuffer;
     UT_String tempBuffer;
 	
@@ -427,7 +427,7 @@ int IE_Imp_MSWrite::read_char (int fcFirst2, int fcLim2) {
     int fcLim, fcMac;
     unsigned char char_page[0x80];
 
-	gchar* pProps = "props";
+	const gchar* pProps = "props";
 	UT_String propBuffer;
 	UT_String tempBuffer;
 	
