@@ -468,9 +468,6 @@ Passepartout_Listener::Passepartout_Listener(PD_Document * pDocument,
 	const char* pszBottomMargin = NULL;
         const char* pszFontFamily = NULL;
         const char* pszFontSize = NULL;
-        
-        const char* FontFamilyStr = NULL;
-        const char* FontSizeStr = NULL;
 
         UT_UTF8String TempStr;
 
