@@ -224,7 +224,7 @@ bool	IE_Imp_Psion_Word_Sniffer::getDlgLabels(const char ** pszDesc,
  */
 static IE_SuffixConfidence IE_Imp_Psion_TextEd_Sniffer__SuffixConfidence[] = {
 	{ "psitext", 	UT_CONFIDENCE_PERFECT 	},
-	{ NULL, 	UT_CONFIDENCE_ZILCH 		}
+	{ "", 	UT_CONFIDENCE_ZILCH 		}
 };
 
 const IE_SuffixConfidence * IE_Imp_Psion_TextEd_Sniffer::getSuffixConfidence ()
