@@ -773,7 +773,7 @@ UT_Error IE_Imp_StarOffice::_loadFile(GsfInput * input) UT_THROWS(()) {
 										return UT_IE_BOGUSDOCUMENT;
 								}
 
-								static gchar* attributes[3] = {
+								static const gchar* attributes[3] = {
 									"props",
 									NULL,
 									NULL
