@@ -234,7 +234,11 @@ void IE_Imp_WML::openTable(const gchar **atts)
 	wml_columns = _getXMLPropValue ("columns", atts);
 
 	if (wml_columns)
+	{
 		m_iColumns = atoi(wml_columns);
+		if (m_iColumns < 1)
+			m_iColumns = 1;
+	}
 	else
 		X_CheckDocument(false); // columns is a required attribute, bail out
 
@@ -383,7 +387,7 @@ void IE_Imp_WML::startElement(const gchar *name,
 		m_parseState = _PS_Block;
 
 		const gchar *p_val = NULL;
-		gchar *buf[3];
+		const gchar *buf[3];
 		bool left = false;
 
 		buf[0] = "props";
@@ -455,7 +459,7 @@ void IE_Imp_WML::startElement(const gchar *name,
 		X_CheckError((m_parseState == _PS_Block) || (m_parseState == _PS_Cell));
 
 		const gchar **p_atts;
-		gchar *buf[3];
+		const gchar *buf[3];
 		buf[0] = "props";
 		buf[1] = NULL;
 	    buf[2] = NULL;
@@ -502,7 +506,7 @@ void IE_Imp_WML::startElement(const gchar *name,
 			}
 		}
 
-		p_atts = const_cast<const gchar **>(buf);
+		p_atts = buf;
 		X_CheckError(_pushInlineFmt(p_atts));
 		X_CheckError(appendFmt(&m_vecInlineFmt));
 		return;
@@ -536,21 +540,21 @@ void IE_Imp_WML::startElement(const gchar *name,
 	case TT_ANCHOR:
 	{
 		X_CheckError((m_parseState == _PS_Block) || (m_parseState == _PS_Cell));
-		gchar *buf[5];
+		const gchar *buf[5];
 		buf[4] = NULL;
 
 		const gchar *p_val = NULL;
-		p_val = _getXMLPropValue(static_cast<const gchar *>("id"), atts);
+		p_val = _getXMLPropValue("id", atts);
 
 		if(p_val)
 		{
 			buf[0] = PT_TYPE_ATTRIBUTE_NAME;
 			buf[1] = "start";
 			buf[2] = PT_NAME_ATTRIBUTE_NAME;
-			buf[3] = (gchar*)p_val;
-			X_CheckError(appendObject(PTO_Bookmark, const_cast<const gchar **>(buf)));
+			buf[3] = p_val;
+			X_CheckError(appendObject(PTO_Bookmark, buf));
 			buf[1] = "end";
-			X_CheckError(appendObject(PTO_Bookmark, const_cast<const gchar **>(buf)));
+			X_CheckError(appendObject(PTO_Bookmark, buf));
 		}
 		return;
 	}
@@ -559,17 +563,17 @@ void IE_Imp_WML::startElement(const gchar *name,
 	{
 		X_CheckError((m_parseState == _PS_Block) || (m_parseState == _PS_Cell));
 
-		gchar *buf[3];
+		const gchar *buf[3];
 		buf[2] = NULL;
 
 		const gchar *p_val = NULL;
-		p_val = _getXMLPropValue(static_cast<const gchar *>("href"), atts);
+		p_val = _getXMLPropValue("href", atts);
 
 		if(p_val)
 		{
 			buf[0] = "xlink:href";
-			buf[1] = (gchar*)p_val;
-			X_CheckError(appendObject(PTO_Hyperlink, const_cast<const gchar **>(buf)));
+			buf[1] = p_val;
+			X_CheckError(appendObject(PTO_Hyperlink, buf));
 		}
 		else //href is required, bail out
 		{
@@ -777,18 +781,18 @@ void IE_Imp_WML::createImage(const char *name, const gchar **atts)
 	X_CheckError (mime);
 	X_CheckError (getDoc()->createDataItem (dataid.utf8_str(), false, pBB, reinterpret_cast<void *>(const_cast<char *>(mime)), NULL));
 
-	gchar *buf[7];
+	const gchar *buf[7];
 	buf[0] = "dataid";
-	buf[1] = (gchar*)dataid.utf8_str();
+	buf[1] = dataid.utf8_str();
 	buf[2] = "alt";
-	buf[3] = (gchar*)alt.utf8_str();
+	buf[3] = alt.utf8_str();
 	buf[4] = NULL;
 	buf[5] = NULL;
 	buf[6] = NULL;
 
 	UT_UTF8String props;
 
-	p_val = _getXMLPropValue(static_cast<const gchar *>("height"), atts);
+	p_val = _getXMLPropValue("height", atts);
 
 	if(p_val)
 	{
@@ -796,7 +800,7 @@ void IE_Imp_WML::createImage(const char *name, const gchar **atts)
 		props += UT_UTF8String_sprintf("%fin", UT_convertDimToInches(UT_convertDimensionless(p_val), DIM_PX));
 	}
 
-	p_val = _getXMLPropValue(static_cast<const gchar *>("width"), atts);
+	p_val = _getXMLPropValue("width", atts);
 
 	if(p_val)
 	{
@@ -807,7 +811,7 @@ void IE_Imp_WML::createImage(const char *name, const gchar **atts)
 		props += UT_UTF8String_sprintf("%fin", UT_convertDimToInches(UT_convertDimensionless(p_val), DIM_PX));
 	}
 
-	p_val = _getXMLPropValue(static_cast<const gchar *>("xml:lang"), atts);
+	p_val = _getXMLPropValue("xml:lang", atts);
 
 	if(p_val)
 	{
@@ -821,7 +825,7 @@ void IE_Imp_WML::createImage(const char *name, const gchar **atts)
 	if(props.length())
 	{
 		buf[4] = PT_PROPS_ATTRIBUTE_NAME;
-		buf[5] = (gchar*)props.utf8_str();
+		buf[5] = props.utf8_str();
 	}
 
 	X_CheckError(appendObject(PTO_Image, const_cast<const gchar **>(buf)));
