@@ -562,7 +562,7 @@ void IE_Imp_WordPerfect::openSpan(const WPXPropertyList &propList)
 	if (m_bHdrFtrOpenCount) return; // HACK
 	UT_DEBUGMSG(("AbiWordPerfect: Appending current text properties\n"));
 	
-	gchar* pProps = "props";
+	const gchar* pProps = "props";
 	UT_String propBuffer;
 	UT_String tempBuffer;
 	
@@ -1124,11 +1124,11 @@ UT_Error IE_Imp_WordPerfect::_appendSection(int numColumns, const float marginLe
 	UT_LocaleTransactor lt(LC_NUMERIC, "C");
 	myProps += UT_String_sprintf("columns:%d; page-margin-left:%.4fin; page-margin-right:%.4fin", numColumns, marginLeft, marginRight);
 	
-	gchar * propsArray[3];
+	const gchar * propsArray[3];
 	propsArray[0] = "props";
-	propsArray[1] = const_cast<gchar*>(reinterpret_cast<const gchar*>(myProps.c_str()));
+	propsArray[1] = myProps.c_str();
 	propsArray[2] = NULL ;
-	X_CheckDocumentError(appendStrux(PTX_Section, (const gchar**)propsArray));
+	X_CheckDocumentError(appendStrux(PTX_Section, propsArray));
 	
 	m_bInSection = true;
 
