@@ -76,7 +76,7 @@ UT_Confidence_t IE_Imp_XSL_FO_Sniffer::recognizeContents(const char * szBuf,
 	UT_uint32 iBytesScanned = 0;
 
 	const char *p;
-	char * magic;
+	const char * magic;
 
 	p = szBuf;
 
@@ -412,15 +412,15 @@ void IE_Imp_XSL_FO::startElement(const gchar *name,
 
 			UT_UTF8String id = UT_UTF8String_sprintf("%d", ++m_iFootnotes);
 
-			gchar *buf[7];
+			const gchar *buf[7];
 			buf[0] = PT_TYPE_ATTRIBUTE_NAME;
 			buf[1] = "footnote_ref";
 			buf[2] = "footnote-id";
-			buf[3] = (gchar*)id.utf8_str();
+			buf[3] = id.utf8_str();
 			buf[4] = PT_PROPS_ATTRIBUTE_NAME;
 			buf[5] = "text-position:superscript";
 			buf[6] = NULL;
-			X_CheckError(appendObject(PTO_Field,const_cast<const gchar **>(buf)));
+			X_CheckError(appendObject(PTO_Field,buf));
 
 			m_bPendingFootnote = true;
 
@@ -437,21 +437,21 @@ void IE_Imp_XSL_FO::startElement(const gchar *name,
 			char * val = g_strdup(id.utf8_str());
 			X_CheckError(val);
 
-			gchar *notebuf[3];
+			const gchar *notebuf[3];
 			notebuf[0] = "footnote-id";
-			notebuf[1] = (gchar*)val;
+			notebuf[1] = val;
 			notebuf[2] = NULL;
-			X_CheckError(appendStrux(PTX_SectionFootnote,const_cast<const gchar **>(notebuf)));
+			X_CheckError(appendStrux(PTX_SectionFootnote,notebuf));
 
-			gchar *anchorbuf[7];
+			const gchar *anchorbuf[7];
 			anchorbuf[0] = PT_TYPE_ATTRIBUTE_NAME;
 			anchorbuf[1] = "footnote_anchor";
 			anchorbuf[2] = "footnote-id";
-			anchorbuf[3] = (gchar*)val;
+			anchorbuf[3] = val;
 			anchorbuf[4] = PT_PROPS_ATTRIBUTE_NAME;
 			anchorbuf[5] = "text-position:superscript";
 			anchorbuf[6] = NULL;
-			X_CheckError(appendObject(PTO_Field,const_cast<const gchar **>(anchorbuf)));
+			X_CheckError(appendObject(PTO_Field,anchorbuf));
 
 			FREEP(val);
 			m_bInFootnote = true;
@@ -562,22 +562,22 @@ void IE_Imp_XSL_FO::startElement(const gchar *name,
 
 				xxx_UT_DEBUGMSG(("FO import: inline props='%s'\n", sBuf.utf8_str()));
 
-				p_atts = static_cast<const gchar **>(&buf[0]);
+				p_atts = &buf[0];
 				X_CheckError(_pushInlineFmt(p_atts));
 				X_CheckError(appendFmt(&m_vecInlineFmt));
 
 				pVal = static_cast<const gchar*>(_getXMLPropValue("id", atts));
 				if(pVal)
 				{
-					gchar *buf2[5];
+					const gchar *buf2[5];
 					buf2[0] = PT_TYPE_ATTRIBUTE_NAME;
 					buf2[1] = "start";
 					buf2[2] = PT_NAME_ATTRIBUTE_NAME;
-					buf2[3] = (gchar*)pVal;
+					buf2[3] = pVal;
 					buf2[4] = NULL;
-					X_CheckError(appendObject(PTO_Bookmark, const_cast<const gchar **>(buf2)));
+					X_CheckError(appendObject(PTO_Bookmark, buf2));
 					buf2[1] = "end";
-					X_CheckError(appendObject(PTO_Bookmark, const_cast<const gchar **>(buf2)));
+					X_CheckError(appendObject(PTO_Bookmark, buf2));
 				}
 			}
 			break;
@@ -591,11 +591,11 @@ void IE_Imp_XSL_FO::startElement(const gchar *name,
 				break;
 			}
 
-			gchar *buf[3];
+			const gchar *buf[3];
 			buf[2] = NULL;
 
 			gchar *p_val = NULL;
-			p_val = (gchar *)_getXMLPropValue(static_cast<const gchar *>("internal-destination"), atts);
+			p_val = (gchar *)_getXMLPropValue("internal-destination", atts);
 
 			if(p_val) //internal
 			{
@@ -603,13 +603,13 @@ void IE_Imp_XSL_FO::startElement(const gchar *name,
 				link += p_val;
 
 				buf[0] = "xlink:href";
-				buf[1] = (gchar*)link.utf8_str();
+				buf[1] = link.utf8_str();
 				X_CheckError(appendObject(PTO_Hyperlink, const_cast<const gchar **>(buf)));
 				m_bOpenedLink = true;
 				break;
 			}
 
-			p_val = (gchar *)_getXMLPropValue(static_cast<const gchar *>("external-destination"), atts);
+			p_val = (gchar *)_getXMLPropValue("external-destination", atts);
 
 			if(p_val) //external
 			{
@@ -620,8 +620,8 @@ void IE_Imp_XSL_FO::startElement(const gchar *name,
 					p_val[len - 2] = '\0';
 					p_val = p_val + 5;
 					buf[0] = "xlink:href";
-					buf[1] = (gchar*)p_val;
-					X_CheckError(appendObject(PTO_Hyperlink, const_cast<const gchar **>(buf)));
+					buf[1] = p_val;
+					X_CheckError(appendObject(PTO_Hyperlink, buf));
 					m_bOpenedLink = true;
 				}
 				else
@@ -705,15 +705,23 @@ void IE_Imp_XSL_FO::startElement(const gchar *name,
 			X_VerifyParseState(_PS_Table);
 			m_parseState = _PS_Block;
 
-			UT_uint32 rowspan = 1, colspan = 1;
+			UT_sint32 rowspan = 1, colspan = 1;
 
 			pVal = static_cast<const gchar*>(_getXMLPropValue("number-columns-spanned", atts));
 			if(pVal)
+			{
 				colspan = atoi(pVal);
+				if(colspan < 1)
+					colspan = 1;
+			}
 
 			pVal = static_cast<const gchar*>(_getXMLPropValue("number-rows-spanned", atts));
 			if(pVal)
+			{
 				rowspan = atoi(pVal);
+				if(rowspan < 1)
+					rowspan = 1;
+			}
 
 
 			X_CheckError(m_TableHelperStack->tdStart(rowspan, colspan, NULL));
@@ -1045,9 +1053,9 @@ void IE_Imp_XSL_FO::createImage(const char *name, const gchar **atts)
 	UT_return_if_fail(mime);
 	X_CheckError (getDoc()->createDataItem (dataid.utf8_str(), false, pBB, reinterpret_cast<void *>(const_cast<char *>(mime)), NULL));
 
-	gchar *buf[5];
+	const gchar *buf[5];
 	buf[0] = "dataid";
-	buf[1] = (gchar*)dataid.utf8_str();
+	buf[1] = dataid.utf8_str();
 	buf[2] = NULL;
 	buf[3] = NULL;
 	buf[4] = NULL;
